@@ -18,7 +18,7 @@ sub conway {
 
     $args->{interval} ||= 200;
 
-    my @cells;
+    my ( @cells, @ids );
     for my $r ( 0 .. $args->{_max_rows} - 1 ) {
         for my $c ( 0 .. $args->{_max_cols} - 1 ) {
             my $cell = sprintf '-r%sc%s', $r, $c;
@@ -30,16 +30,28 @@ sub conway {
                     height => '30px',
                     style  => { 'background-color' => $args->{off} },
                 };
+            push @ids, join( '-', $r, $c ) if $args->{$cell};
         }
     }
 
+    # find and remove 'file' param and its value if found
+    if ($args->{file} and $args->{file} =~ /\.(gif|png|jpe?g)$/) {
+        my $index = 0;
+        for (0 .. $#_) {
+            next if ref $_[$_];
+            if ($_[$_] eq 'file') { $index = $_; last }
+        }
+        splice @_, $index, 2;
+        push @_, ( fill => $args->{fill} );
+    }
+
     my @args = (
         @cells,
         caption  => { '<button id="toggle" onClick="toggle()">Start</button>' => { align => 'bottom' } },
         @_,
     );
 
-    my $js    = _javascript( %$args );
+    my $js    = _javascript( %$args, ids => \@ids );
     my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
     return $js . $table;
 }
@@ -51,6 +63,7 @@ sub _javascript {
         $args{_max_rows},
         $args{_max_cols},
         $args{interval},
+        join( ',', map "'$_'", @{ $args{ids} } ),
         $args{off},
         join( ',', map "'$_'", @{ $args{colors} } ),
     ;
@@ -68,6 +81,7 @@ var ROW = %s;
 var COL = %s;
 var INTERVAL = %s;
 var tid;
+var ids = [ %s ];
 
 function Cell (id) {
     this.id         = id;
@@ -132,6 +146,13 @@ $(document).ready(function(){
         }
     }
 
+    // activate any "pre-loaded" IDs
+    for (var i = 0; i < ids.length; i++) {
+        var matches  = ids[i].match( /(\d+)-(\d+)/ );
+        var selected = MATRIX[matches[1]][matches[2]];
+        selected.grow( 1 );
+    }
+
 });
 
 function update() {
@@ -205,6 +226,17 @@ activate a fading effect like so:
   # color names via Color::Library
   conway( on => 'red', off => 'gray', fade => 1 )
 
+You can also load a file and pre-populate a game grid if you know which
+color will be used as 'off'. This example uses #F8F8F8 and tweaks the block
+size up to 16:
+
+  conway( file => 'conway.png', off => 'F8F8F8', block => 16 )
+
+Notice that even though a hex coded color was passed, no leading hash mark was
+specified. Work is being done to correct this inconsistent interface. Work is
+also being done to guess the color for 'off' (probably by finding the lightest
+color found).
+
 Uses Google's jQuery API unless you specify another URI via
 the C<jquery> param. Javascript will be minified
 via L<Javascript::Minifier> if it is installed.
